@@ -309,7 +309,7 @@ class DictionaryFilter(CompressionFilter):
     >>> with tempfile.TemporaryDirectory() as tmp:
     ...     dom = tiledb.Domain(tiledb.Dim(domain=(0, 9), tile=2, dtype=np.uint64))
     ...     a1 = tiledb.Attr(name="a1", dtype=np.int64,
-    ...                      filters=tiledb.FilterList([tiledb.DictionaryEncodingFilter()]))
+    ...                      filters=tiledb.FilterList([tiledb.DictionaryFilter()]))
     ...     schema = tiledb.ArraySchema(domain=dom, attrs=(a1,))
     ...     tiledb.DenseArray.create(tmp + "/array", schema)
 
@@ -510,11 +510,11 @@ class FloatScaleFilter(Filter):
     """
     Filter that stores floats as integers in a reduced representation via scaling.
     The reduced storage space is in lieu of some precision loss. The float scaling
-    filter takes three parameters: the scale, the offset, and the byte width.
-    On write, the float scaling filter applies the scale factor and offset,
-    and stores the value of round((raw_float - offset) / scale) as an
+    filter takes three parameters: the factor, the offset, and the bytewidth.
+    On write, the float scaling filter applies the factor (scaling factor) and offset,
+    and stores the value of round((raw_float - offset) / factor) as an
     integer with the specified NumPy dtype.
-    On read, the float scaling filter will reverse the scale factor and offset,
+    On read, the float scaling filter will reverse the factor and offset,
     and returns the floating point data, with a potential loss of precision.
     :param factor: the scaling factor used to translate the data
     :type factor: float
@@ -679,7 +679,7 @@ class WebpFilter(Filter):
 
     def __init__(
         self,
-        input_format: int = None,
+        input_format: lt.WebpInputFormat = None,
         quality: float = None,
         lossless: bool = None,
         ctx: "Ctx" = None,
@@ -693,21 +693,21 @@ class WebpFilter(Filter):
 
         if input_format is not None:
             self._set_option(
-                lt.Context(self._ctx.__capsule__(), False),
+                self._ctx,
                 lt.FilterOption.WEBP_INPUT_FORMAT,
-                input_format,
+                lt.WebpInputFormat(input_format),
             )
 
         if quality is not None:
             self._set_option(
-                lt.Context(self._ctx.__capsule__(), False),
+                self._ctx,
                 lt.FilterOption.WEBP_QUALITY,
                 float(quality),
             )
 
         if lossless is not None:
             self._set_option(
-                lt.Context(self._ctx.__capsule__(), False),
+                self._ctx,
                 lt.FilterOption.WEBP_LOSSLESS,
                 lossless,
             )
@@ -721,22 +721,24 @@ class WebpFilter(Filter):
 
     @property
     def input_format(self):
-        return self._get_option(
-            lt.Context(self._ctx.__capsule__(), False),
-            lt.FilterOption.WEBP_INPUT_FORMAT,
+        return lt.WebpInputFormat(
+            self._get_option(
+                self._ctx,
+                lt.FilterOption.WEBP_INPUT_FORMAT,
+            )
         )
 
     @property
     def quality(self):
         return self._get_option(
-            lt.Context(self._ctx.__capsule__(), False),
+            self._ctx,
             lt.FilterOption.WEBP_QUALITY,
         )
 
     @property
     def lossless(self):
         return self._get_option(
-            lt.Context(self._ctx.__capsule__(), False),
+            self._ctx,
             lt.FilterOption.WEBP_LOSSLESS,
         )
 
@@ -798,18 +800,15 @@ class FilterList(lt.FilterList):
         filters: Sequence[Filter] = None,
         chunksize: int = None,
         ctx: "Ctx" = None,
-        _lt_obj=None,
-        _capsule=None,
+        _lt_obj: lt.FilterList = None,
+        _capsule: "PyCapsule" = None,
     ):
         self._ctx = ctx or default_ctx()
 
         if _capsule is not None:
             super().__init__(self._ctx, _capsule)
         elif _lt_obj is not None:
-            super().__init__(self._ctx)
-            for i in range(_lt_obj._nfilters()):
-                self._add_filter(_lt_obj._filter(i))
-            chunksize = _lt_obj._chunksize
+            super().__init__(_lt_obj)
         else:
             super().__init__(self._ctx)
             if filters is not None:
