@@ -6,6 +6,37 @@ import warnings
 import tiledb
 from tiledb.tests.common import DiskTestCase
 
+all_filter_types = [
+    tiledb.NoOpFilter,
+    tiledb.GzipFilter,
+    tiledb.ZstdFilter,
+    tiledb.LZ4Filter,
+    tiledb.RleFilter,
+    tiledb.Bzip2Filter,
+    tiledb.DoubleDeltaFilter,
+    tiledb.DictionaryFilter,
+    tiledb.BitWidthReductionFilter,
+    tiledb.BitShuffleFilter,
+    tiledb.ByteShuffleFilter,
+    tiledb.PositiveDeltaFilter,
+    tiledb.ChecksumSHA256Filter,
+    tiledb.ChecksumMD5Filter,
+    tiledb.FloatScaleFilter,
+]
+
+
+def filter_applicable(filter_type, attr_type) -> bool:
+    """Return bool indicating filter applicability to a given attribute type."""
+    if not isinstance(attr_type, type):
+        # guard issubclass below: first argument must be a type
+        return True
+    elif issubclass(attr_type, np.floating) and filter_type in [
+        tiledb.DoubleDeltaFilter
+    ]:
+        return False
+
+    return True
+
 
 class TestFilterTest(DiskTestCase):
     def test_filter(self):
@@ -35,59 +66,49 @@ class TestFilterTest(DiskTestCase):
         self.assertEqual(len(attr.filters), 2)
         self.assertEqual(attr.filters.chunksize, filter_list.chunksize)
 
-    def test_filter_list(self):
+    @pytest.mark.parametrize("attr_type", [np.int64])
+    @pytest.mark.parametrize("filter_type", all_filter_types)
+    def test_filter_list(self, attr_type, filter_type):
+        if not filter_applicable(filter_type, attr_type):
+            pytest.mark.skip("Filter not supported for attribute type '{attr_type}'")
+
         # should be constructible without a `filters` keyword arg set
         filter_list1 = tiledb.FilterList()
-        filter_list1.append(tiledb.GzipFilter())
+        filter_list1.append(filter_type())
         self.assertEqual(len(filter_list1), 1)
+        repr(filter_list1)
 
         filter_list2 = [x for x in filter_list1]
-        attr = tiledb.Attr(filters=filter_list2)
+        attr = tiledb.Attr(filters=filter_list2, dtype=attr_type)
         self.assertEqual(len(attr.filters), 1)
 
-    def test_all_filters(self):
+    @pytest.mark.parametrize("filter", all_filter_types)
+    def test_all_filters(self, filter):
         # test initialization
-        filters = [
-            tiledb.NoOpFilter(),
-            tiledb.GzipFilter(),
-            tiledb.ZstdFilter(),
-            tiledb.LZ4Filter(),
-            tiledb.RleFilter(),
-            tiledb.Bzip2Filter(),
-            tiledb.DoubleDeltaFilter(),
-            tiledb.DictionaryFilter(),
-            tiledb.BitWidthReductionFilter(),
-            tiledb.BitShuffleFilter(),
-            tiledb.ByteShuffleFilter(),
-            tiledb.PositiveDeltaFilter(),
-            tiledb.ChecksumSHA256Filter(),
-            tiledb.ChecksumMD5Filter(),
-            tiledb.FloatScaleFilter(),
-        ]
+
         # make sure that repr works and round-trips correctly
-        for f in filters:
-            # some of these have attributes, so we just check the class name here
-            self.assertTrue(type(f).__name__ in repr(f))
+        # some of these have attributes, so we just check the class name here
+        self.assertTrue(filter.__name__ in repr(filter))
 
-            tmp_globals = dict()
-            setup = "from tiledb import *"
-            exec(setup, tmp_globals)
+        tmp_globals = dict()
+        setup = "from tiledb import *"
+        exec(setup, tmp_globals)
 
-            filter_repr = repr(f)
-            new_filter = None
-            try:
-                new_filter = eval(filter_repr, tmp_globals)
-            except Exception:
-                warn_str = (
-                    """Exception during FilterTest filter repr eval"""
-                    + """, filter repr string was:\n"""
-                    + """'''"""
-                    + """\n{}\n'''""".format(filter_repr)
-                )
-                warnings.warn(warn_str)
-                raise
+        filter_repr = repr(filter())
+        new_filter = None
+        try:
+            new_filter = eval(filter_repr, tmp_globals)
+        except Exception as exc:
+            warn_str = (
+                """Exception during FilterTest filter repr eval"""
+                + """, filter repr string was:\n"""
+                + """'''"""
+                + """\n{}\n'''""".format(filter_repr)
+            )
+            warnings.warn(warn_str)
+            raise
 
-            self.assertEqual(new_filter, f)
+        self.assertEqual(new_filter, filter())
 
     def test_dictionary_encoding(self):
         path = self.path("test_dictionary_encoding")
